@@ -3,19 +3,12 @@ NULL
 
 #' Calculate boundary data for planning units
 #'
-#' This function calculates boundary length data for
-#' [PBSmapping::PolySet()], [sp::SpatialPolygons()], and
-#' [sp::SpatialPolygonsDataFrame()] objects. Be aware that this
+#' This function calculates boundary length data. Be aware that this
 #' function is designed with performance in mind, and as a consequence, if this
 #' function is used improperly then it may crash R. Furthermore, multipart
 #' polygons with touching edges will likely result in inaccuracies.
-#' If argument set to [sp::SpatialPolygons()] or
-#' [sp::SpatialPolygonsDataFrame()], this will be converted to
-#' PolySet before processing.
 #'
-#' @param x [PBSmapping::PolySet()],
-#'   [sp::SpatialPolygons()] or
-#'   [sp::SpatialPolygonsDataFrame()] object.
+#' @param x [sf::st_sf()] or `PBSMapping::PolySet` object.
 #'
 #' @param tol `numeric` to specify precision of calculations. In other
 #'   words, how far apart vertices have to be to be considered different?
@@ -25,7 +18,7 @@ NULL
 #' @param edge.factor `numeric` to scale boundary lengths for edges that
 #'   do not have any neighbors, such as those that occur along the margins.
 #'
-#' @return `data.frame` with 'id1' (`integer`), 'id2'
+#' @return A `data.frame` with 'id1' (`integer`), 'id2'
 #'   (`integer`), and 'amount' (`numeric`) columns.
 #'
 #' @seealso This function is based on the algorithm in QMARXAN
@@ -33,6 +26,7 @@ NULL
 #'   length.
 #'
 #' @examples
+#' \dontrun{
 #' # simulate planning units
 #' sim_pus <- sim.pus(225L)
 #'
@@ -41,29 +35,39 @@ NULL
 #'
 #' # print summary of boundary data
 #' summary(bound.dat)
-#'
+#' }
 #' @export
-calcBoundaryData <- function(x, tol, length.factor, edge.factor)
+calcBoundaryData <- function(x, tol, length.factor, edge.factor) {
   UseMethod("calcBoundaryData")
+}
 
 #' @rdname calcBoundaryData
 #'
 #' @method calcBoundaryData PolySet
 #'
 #' @export
-calcBoundaryData.PolySet <- function(x, tol = 0.001, length.factor = 1.0,
+calcBoundaryData.PolySet <- function(x,
+                                     tol = 0.001,
+                                     length.factor = 1.0,
                                      edge.factor = 1.0) {
-  assertthat::assert_that(inherits(x, "PolySet"), assertthat::is.scalar(tol),
-                          assertthat::is.scalar(length.factor),
-                          assertthat::is.scalar(edge.factor))
-  ret <- rcpp_calcBoundaryDF(x, tolerance = tol, lengthFactor = length.factor,
-                             edgeFactor = edge.factor)
+  # assert arguments are valid
+  assertthat::assert_that(
+    inherits(x, "PolySet"),
+    assertthat::is.scalar(tol),
+    assertthat::is.scalar(length.factor),
+    assertthat::is.scalar(edge.factor)
+  )
+  # calculate boundary data
+  ret <- rcpp_calcBoundaryDF(
+    x, tolerance = tol, lengthFactor = length.factor, edgeFactor = edge.factor
+  )
   if (length(ret$warnings) != 0) {
     warning(paste0("Invalid geometries detected, see \"warnings\" attribute ",
                    "for more information."))
     attr(ret$bldf, "warnings") <- ret$warnings
   }
-  return(ret$bldf)
+  # return result
+  ret$bldf
 }
 
 #' @rdname calcBoundaryData
@@ -71,9 +75,29 @@ calcBoundaryData.PolySet <- function(x, tol = 0.001, length.factor = 1.0,
 #' @method calcBoundaryData SpatialPolygons
 #'
 #' @export
-calcBoundaryData.SpatialPolygons <- function(x, tol = 0.001,
+calcBoundaryData.SpatialPolygons <- function(x,
+                                             tol = 0.001,
                                              length.factor = 1.0,
                                              edge.factor = 1.0) {
-  return(calcBoundaryData(rcpp_Polygons2PolySet(x@polygons), tol,
-                          length.factor, edge.factor))
+  .Defunct(
+    msg = paste(
+      "support for sp::SpatialPolygons data has been deprecated,",
+      "use sf::st_as_sf() to convert to an sf::st_sf() object and try again"
+    )
+  )
+}
+
+#' @rdname calcBoundaryData
+#'
+#' @method calcBoundaryData sf
+#'
+#' @export
+calcBoundaryData.sf <- function(x,
+                                tol = 0.001,
+                                length.factor = 1.0,
+                                edge.factor = 1.0) {
+  calcBoundaryData(
+    rcpp_Polygons2PolySet(sf::as_Spatial(x)@polygons),
+    tol, length.factor, edge.factor
+  )
 }
