@@ -37,12 +37,9 @@ test_that("demand.points (ks, geographic space)", {
 })
 
 test_that("demand.points (ks, attribute space)", {
-  # load data
-  data(cs_spp, cs_space)
   # generate points
-  pts <- sp::SpatialPoints(coords = randomPoints(cs_spp[[1]], n = 10,
-                                                 prob = TRUE))
-  space.pts <- raster::extract(cs_space[[1]], pts)
+  pts <- randomPoints(cs_spp[[1]], n = 10, prob = TRUE)
+  space.pts <- as.matrix(terra::extract(cs_space[[1]], pts))
   # create demand points
   dp <- make.DemandPoints(points = space.pts, n = 100L, kernel.method = "ks")
   # check objects
@@ -57,15 +54,17 @@ test_that("demand.points (ks, attribute space)", {
 test_that("demand.points (hypervolume, geographic space)", {
   # skip on cran due to issues in hypervolume's progress bars
   skip_on_cran()
-  # load data
-  data(cs_spp)
   # generate points
-  pts <- sp::SpatialPoints(coords = randomPoints(cs_spp[[1]], n = 100,
-                                                 prob = TRUE))@coords
+  pts <- sp::SpatialPoints(
+    coords = randomPoints(cs_spp[[1]],  n = 100, prob = TRUE)
+  )@coords
   # create demand points
-  dp <- make.DemandPoints(points = pts, n = 100L,
-                          kernel.method = "hypervolume",
-                          verbose = FALSE)
+  dp <- make.DemandPoints(
+    points = pts,
+    n = 100L,
+    kernel.method = "hypervolume",
+    verbose = FALSE
+  )
   # check objects
   expect_is(dp, "DemandPoints")
   expect_equal(ncol(dp@coords), 2)
@@ -78,15 +77,17 @@ test_that("demand.points (hypervolume, geographic space)", {
 test_that("demand.points (hypervolume, attribute space)", {
   # skip on cran due to issues in hypervolume's progress bars
   skip_on_cran()
-  # load data
-  data(cs_spp, cs_space)
   # generate points
-  pts <- sp::SpatialPoints(coords = randomPoints(cs_spp[[1]], n = 100,
-                           prob = TRUE))@coords
+  pts <- sp::SpatialPoints(
+    coords = randomPoints(cs_spp[[1]], n = 100, prob = TRUE)
+  )@coords
   # create demand points
-  dp <- make.DemandPoints(points = pts, n = 100L,
-                          kernel.method = "hypervolume",
-                          verbose = FALSE)
+  dp <- make.DemandPoints(
+    points = pts,
+    n = 100L,
+    kernel.method = "hypervolume",
+    verbose = FALSE
+  )
   # check objects
   expect_is(dp, "DemandPoints")
   expect_equal(ncol(dp@coords), 2)
